package com.twomee.appear2meedemo;

/**
 * Created by 2Mee Ltd on 08/06/17.
 */


import android.app.AlertDialog;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.net.Uri;
import android.os.Bundle;
import androidx.annotation.NonNull;
import androidx.core.app.ActivityCompat;
import androidx.appcompat.app.AppCompatActivity;
import android.text.InputType;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.CompoundButton;
import android.widget.EditText;
import android.widget.Switch;

import com.google.firebase.messaging.RemoteMessage;
import com.twomee.appear2mee.Appear2mee;


import org.json.JSONException;
import org.json.JSONObject;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.TimeZone;
import java.util.UUID;

public class MainActivity extends AppCompatActivity implements ActivityCompat.OnRequestPermissionsResultCallback  {

    private static final String TAG = "MainActivity";
    private Button userIDbutton;
    private Switch switch_permission, switch_wifi, switch_service;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        userIDbutton = (Button) findViewById(R.id.userIDbutton);
        switch_permission = (Switch) findViewById(R.id.switch_permission);
        switch_permission.setChecked(Appear2mee.hasDownloadPermission());
        switch_permission.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton compoundButton, boolean b) {
                Appear2mee.downloadPermission(b);
            }
        });
        switch_wifi = (Switch) findViewById(R.id.switch_wifionly);
        switch_wifi.setChecked(Appear2mee.hasWifiOnlyPermission());
        switch_wifi.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton compoundButton, boolean b) {
                Appear2mee.WifiOnlyPermission(b);
            }
        });
        switch_service = (Switch) findViewById(R.id.switch_service);
        switch_service.setChecked(Appear2mee.hasServicePermission());
        switch_service.setOnCheckedChangeListener(new CompoundButton.OnCheckedChangeListener() {
            @Override
            public void onCheckedChanged(CompoundButton compoundButton, boolean b) {
                Appear2mee.servicePermission(b);
            }
        });

        userIDbutton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                AlertDialog.Builder builder = new AlertDialog.Builder(view.getContext());
                builder.setTitle("userID");

                // Set up the input
                final EditText input = new EditText(view.getContext());
                String userid = Appear2mee.getUserID();
                if(userid != null) {
                    input.setText(userid);
                }
                input.setInputType(InputType.TYPE_CLASS_TEXT);
                builder.setView(input);

                // Set up the buttons
                builder.setPositiveButton("OK", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialogInterface, int i) {
                        String text = input.getText().toString();// TODO check text and alert if bad.
                        setUserID(text);
                        Appear2mee.registerUserID(text);
                    }
                });
                builder.setNegativeButton("Cancel", new DialogInterface.OnClickListener() {
                    @Override
                    public void onClick(DialogInterface dialog, int which) {
                        dialog.cancel();
                    }
                });

                builder.show();
            }
        });
        Appear2mee.startLocationService(this);
    }


    private void setUserID(String user) {
        SharedPreferences pref = getApplicationContext().getSharedPreferences("AppPreferences", 0); // 0 - for private mode
        SharedPreferences.Editor editor = pref.edit();
        editor.putString("userID", user ); // Storing string
        editor.commit(); // commit changes
    }



    /**
     * ResponseListenerCallback received when a permissions request has been completed.
     */
    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions,
                                           @NonNull int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);
        if(requestCode == Appear2mee.LOCATION_SERVICE_REQUEST_CODE) { // you do not need to check the requestCode
            Appear2mee.startLocationService(this);
        }
    }


    public void onChannelClick(View view) {
        Intent _tagsActivity = new Intent(this, TagsActivity.class);
        startActivity(_tagsActivity);
    }

    public void onPrivacyClick(View view) {
        Uri uri = Uri.parse("https://2mee.com/privacy-policy/");
        Intent i = new Intent(Intent.ACTION_VIEW);
        i.setData(uri);
        startActivity(i);
    }

    static boolean toggleRich = false;
    static boolean toggleRich2 = false;
    public void richTextNotification(View view) {
        boolean isVideo = false;
        boolean isAudio = false;
        try {
            String img = null;
            String aud = null;
            String jobId;

            if(toggleRich2) {
                if (toggleRich) {
                    img = "https://exchange.cdnedge.bluemix.net/web/flowerPot.png";
                    aud = "https://exchange.cdnedge.bluemix.net/web/crowd-cheering.mp3";
                    isAudio = true;
                    jobId = "pnga60730a9555731f257f3b00f09890485";
                } else {
                    img = "https://exchange.cdnedge.bluemix.net/web/SampleVideo_1280x720_1mb.mp4";
                    isVideo = true;
                    jobId = "gsvgreb1e19a1f0c2105be90d4fc75b7303ade";
                }
            } else {
                if(toggleRich) {
                    img = "https://exchange.cdnedge.bluemix.net/web/Xtumblr_inline_mjx5ioXh8l1qz4rgp.gif";
                    jobId = "2gsvgreb1e19a1f0c2105be90d4fc75b7303ade";
                } else {
                    jobId = "textvgreb1e19a1f0c2105be90d4fc75b7303ade";
                }
            }

            JSONObject fms = new JSONObject();
            JSONObject fmsViewInformation = new JSONObject();
            fms.put("fm", fmsViewInformation);
            fmsViewInformation.put("jobId", jobId);
            if(isVideo) {
                fmsViewInformation.put("vid", img);
            } else {
                if(img != null) {
                    fmsViewInformation.put("img", img);
                }
            }
            if(isAudio) {
                fmsViewInformation.put("aud", aud);
            }


            fmsViewInformation.put("jobId",  UUID.randomUUID().toString());
            fmsViewInformation.put("subtitle", "More Title Information");
            fmsViewInformation.put("message", "One more test message");
            fmsViewInformation.put("fbTitle", "FB, A Title");
            fmsViewInformation.put("fbSub", "FB, More Title Information");
            fmsViewInformation.put("fbBody", "FB, One more test message");
            fmsViewInformation.put("action", "Press me too.");
            fmsViewInformation.put("expiryTime", 60000);
            fmsViewInformation.put("playTime", getTime(+(1 * 10))); // play in 10 secs.
            fmsViewInformation.put("fs",1);
            fmsViewInformation.put("about", "[ { \"__openExternalURL\":\"https://www.google.com\"}, { \"link2\":\"about2.html\"} ]" );
            //if(toggleRich)
            fmsViewInformation.put("cb", "1");

            if(!toggleRich && !toggleRich2) {
                // build in open link in browser
                // as long as overrideDefaultSettings.put(Appear2mee.kOpenExternalURLAutomatically,"true"); is not set to false.
                fmsViewInformation.put("title", "Open Link");
                fmsViewInformation.put("about", "[ { \"__openExternalURL\":\"https://www.google.com\"}, { \"link2\":\"about2.html\"} ]" );
            } else {
                fmsViewInformation.put("title", "A Title");
                fmsViewInformation.put("about", "[ { \"page\":\"about.html\"}, { \"page\":\"about2.html\"} ]");
            }

            toggleRich = !toggleRich;
            if(toggleRich) toggleRich2 = !toggleRich2;

            RemoteMessage.Builder _notification = new RemoteMessage.Builder("bridge2mee");
            _notification.addData("payload", fms.toString());
            RemoteMessage notificationMessage = _notification.build();
            Log.i(TAG, "payload:" + fms.toString());
            Appear2mee.testNotification(notificationMessage);
        } catch (JSONException e) {
            e.printStackTrace();
        }
    }


    static boolean toggle = false;
    public void faceMessage(View view) {
        try {
            String url = "https://exchange.cdnedge.bluemix.net/20a38e01-cbd6-4bfc-9fb8-c99a1cb4e844-14391119-4023-42be-b03a-a86278f10f91-take-1.mp4";
            String jobId = "a60730a9555731f257f3b00f09890485_2ee";

            if(toggle) {
                url = "https://exchange.cdnedge.bluemix.net/ecc6df1c-221d-4a8c-8b2a-096271cb46cc-319bfc80-abfc-401d-9ff8-2a0698218882-take-1.mp4";
                jobId = "1e19a1f0c2105be90d4fc75b7303ade3_cr";
            }
            toggle = !toggle;

            JSONObject fms = new JSONObject();
            JSONObject fmsViewInformation = new JSONObject();
            fms.put("fm", fmsViewInformation);
            fmsViewInformation.put("jobId", jobId);
            fmsViewInformation.put("url", url);
            fmsViewInformation.put("title", "A Title");
            fmsViewInformation.put("subtitle", "More Title Information");
            fmsViewInformation.put("message", "One more test message");
            fmsViewInformation.put("fbTitle", "FB, A Title");
            fmsViewInformation.put("fbSub", "FB, More Title Information");
            fmsViewInformation.put("fbBody", "FB, One more test message");
            fmsViewInformation.put("about", "[ { \"page\":\"about.html\"}, { \"page\":\"about2.html\"}, { \"setColor\":\"true\"} ]" );
            fmsViewInformation.put("expiryTime", 300);
            fmsViewInformation.put("action", "Press Me");
            fmsViewInformation.put("playTime", getTime(-(1 * 20))); // play now!
            RemoteMessage.Builder _notification = new RemoteMessage.Builder("bridge2mee");
            _notification.addData("payload", fms.toString());
            RemoteMessage notificationMessage = _notification.build();
            Appear2mee.testNotification(notificationMessage);
        } catch (JSONException e) {
            e.printStackTrace();
        }
    }

    String getTime(int time) {
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd'T'HH:mm:ss.SSS'Z'");
        dateFormat.setTimeZone(TimeZone.getTimeZone("UTC"));
        Date _currentDate = new Date();
        _currentDate.setTime(_currentDate.getTime() + (time * 1000));
        return dateFormat.format(_currentDate);
    }

    public void onMessageClick(View view) {
        Appear2mee.getMessage("Welcome Message", new Appear2mee.MessageReadyListener() {
            @Override
            public void ready(String name, Bundle item) {
                if(item == null) return;
                Log.i(TAG,"Message Ready:" + name);
                Appear2mee.displayMessage(item,name);
            }
        });
    }

}
